package com.xinelu.manage.service.basesportinfo;

import com.xinelu.manage.domain.basesportinfo.BaseSportInfo;

import java.util.List;


/**
 * 运动知识库Service接口
 *
 * @author xinelu
 * @date 2024-05-16
 */
public interface IBaseSportInfoService {
    /**
     * 查询运动知识库
     *
     * @param id 运动知识库主键
     * @return 运动知识库
     */
    BaseSportInfo selectBaseSportInfoById(Long id);

    /**
     * 查询运动知识库列表
     *
     * @param baseSportInfo 运动知识库
     * @return 运动知识库集合
     */
    List<BaseSportInfo> selectBaseSportInfoList(BaseSportInfo baseSportInfo);

    /**
     * 新增运动知识库
     *
     * @param baseSportInfo 运动知识库
     * @return 结果
     */
    int insertBaseSportInfo(BaseSportInfo baseSportInfo);

    /**
     * 修改运动知识库
     *
     * @param baseSportInfo 运动知识库
     * @return 结果
     */
    int updateBaseSportInfo(BaseSportInfo baseSportInfo);

    /**
     * 批量删除运动知识库
     *
     * @param ids 需要删除的运动知识库主键集合
     * @return 结果
     */
    int deleteBaseSportInfoByIds(Long[] ids);

    /**
     * 删除运动知识库信息
     *
     * @param id 运动知识库主键
     * @return 结果
     */
    int deleteBaseSportInfoById(Long id);
}
